*** Outline

* # 3. Graphs
* # 3.1 Histograms
* # 3.2 Box Plots
* # 3.3 Scatterplots and Overlays
* # 3.4 Line Plots and Connected-Line Plots
* # 3.5 Other Twoway Plot Types 
* # 3.6 Bar Charts and Pie Charts
* # 3.7 Retrieving and Combining Graphs
* # 3.8 Graph Editor
* # 3.9 Symmetry and Quantile Plots [extra topic]
* # 3.10 Adding Text to Graphs [extra topic]

* [based on Hamilton L. C. (2013). Statistics with STATA: Version 12, 8th Edition. Cengage. University of New Hampshire, Ch. 3]

version 12.1
clear all
set more off

* # Setting  working directory to whereever stata is working from 

cd "T:\Labor_economics\ES\ES3\Datasets"

* ### 3. Graphs ###
* #################

* ######################
* ### 3.1 Histograms ###

* The command "histogram" displays the distribution of measurement variables. 

* Consider dataset Nations2.dta, which contains human-development indicators gathered by the United Nations.

use Nations2.dta, clear
describe
histogram adfert, percent

// The Figure shows a simple histogram of adfert, the adolescent fertility rate.

* Options can be listed in any order following the comma in a graph command. 
// Figure above illustrates one option: percent (instead of density, the default) is shown on the vertical axis.
// Once a graph is on screen, menu choices provide the easiest way to print it, save it to disk, 
// or copy and paste it into another program such as a word processor.

* The next Figure contains a version of the same histogram but with some optional improvements:

histogram adfert, frequency start(0) width(10) ///
xlabel(0(20)200) xtick(10(20)210) ///
ylabel(0(5)35, grid gmax) ///
title("Adolescent fertility rate in 194 nations")

* # frequency Frequencies are shown on the vertical (y) axis.
* # start(0) The histogram's first bar (bin) starts at 0.
* # width(10) The width of each bar (bin) is 10.
* # xlabel(0(20)200) The x axis is labeled from 0 to 200, in increments of 20.
* # xtick(10(20)210) The x axis has tick marks from 10 to 210, in increments of 20.
* # ylabel(0(5)35, grid gmax) The y axis is labeled from 0 to 35, in increments of 5. 
// A grid of horizontal lines is drawn, including a line at the maximum value.
* # title("Adolescent fertility rate in 194 nations") The graph has a title at top.

* One option that histogram shares with other graph types is the ability to create multiple small graphs for each value of a specified variable, 
// using a by(varname) option. 
* The next Figure illustrates histograms of adfert for each of the five regions, along with a sixth (total) histogram showing the distribution for all regions.

histogram adfert, percent start(0) width(10) by(region, total)


* #####################
* ### 3.2 Box Plots ###

* Box plots convey information about center, spread, symmetry and outliers at a glance. 

* The next Figure is a simple box plot of adfert (adolescent fertility rate)

graph box adfert

/* Box plots in general are composed of a box, two whiskers, two fences, and some marker symbols. The box is the rectangle in the middle of the graph. 
The lower border of the box is the first quartile; the upper border is the third quartile. The line in the middle of the box is the median.
The height of the box therefore shows the interquartile range.

The whiskers are two vertical lines below and above the box, which end with small horizontal lines called the fences.
The upper fence is the highest value of the distribution that is smaller than or equal to the third quartile plus 1.5 times the interquartile range.
The lower fence is the lowest value of the distribution that is greater than or equal to the first quartile minus 1.5 times the interquartile range.

Observations below the lower fence or above the upper fence are regarded as outliers and are plotted with single plot symbols.

Box plots provide much information about a distribution. You can directly infer the position of the distribution from the position of the box along the y axis.
Fifty percent of the observations have values between the lower and upper bounds of the box.
You can infer the dispersion of the distribution by the size of the box, by the length of the whiskers, and by the positions of the outliers.
Moreover, you can see the symmetry or skewness of the distribution: in symmetric distributions, the distances between the median and the lower
and upper bounds of the box are equal. Also the whiskers should be of equal length and the outliers above and below should be equally spaced.
If the outliers, the whiskers, or the box are squeezed at the bottom, the distribution is skewed to the right.
If they are squeezed at the top, it is skewed to the left. */

// From the Figure one can conclude about the positive skew of this distribution. One can also see five high outliers. 

* The next Figure identifies the adfert outliers by labeling their markers with values of variable country (country names). 
// It also specifies a non-default title for the y axis. 
// Specifying marker(1) in this example means that this option refers to the first-named y variable. 
// There is only one y variable here, but in other cases we could have two or more, and mark their outliers in distinct ways.

graph box adfert, marker(1, mlabel(country)) ///
ytitle("Births per 1,000 females 15-19")

* One of the most common applications for box plots involves comparing the distribution of one variable over categories of a second 
// using the options over() or by().. 

// The next Figure compares the distribution of adfert across region. 
// The overall median is indicated by a horizontal line placed by the yline(39.3) option.

graph box adfert, marker(1, mlabel(country)) yline(39.3) over(region)

* Box plots can have a horizontal orientation instead of vertical, via the "graph hbox command".

* The next Figure illustrates using per capita carbon dioxide emissions (CO2)
// This example also shows off several title or labeling options, which could be applied to any type of graph. 
// The note( ) and caption( ) options place text below the graph.
// In this figure, Statistics with Stata appears in bold, and Example of horizontal box plots in italics. 
// In the ytitle (y axis title, which in a horizontal box plot refers to the horizontal axis), CO2 is given its proper subscript. 
// Type "help graph text" to see other possibilities and examples.

graph hbox co2, over(region) ///
note("note: {bf:Statistics with Stata}, version 12") ///
caption("caption: United Nations Human Development Report 2011") ///
title("title: {it:Example of horizontal box plots}") ///
ytitle("ytitle: Tons of CO{subscript:2} emitted per capita")

// Numerous options control the appearance, shading and details of boxes in a box plot; type "help graph box" for a list. 


* #####################################
* ### 3.3 Scatterplots and Overlays ###

* Scatterplots belong to a broad family called twoway graphs. 
// Statas basic scatterplot command has the form

// "graph twoway scatter y x"

* Consider the Nations2.dta dataset
* We can plot life (life expectance) against school (mean years of schooling), with the result shown in the next Figure

graph twoway scatter life school

// Each point in the Figure represents one nation.

* We can use xlabel, xtitle, ylabel and so forth to control x or y axis labels, titles etc. 
* Scatterplots also allow control of the shape, color, size, labeling and other attributes of markers. 
// Type "help scatter" for a complete list of markers and other options.
// Type "help colorstyle" for a list of available colors, which can also apply to bars, lines, text and other elements of any Stata graph.

* One interesting possibility with scatterplots is to make symbol size (area) proportional to a third variable, 
// thereby giving the data points different visual weight. 

// This is done in the next Figure, using the [fweight=varname] or frequency weight feature. Hollow circles, msymbol(Oh), provide a suitable shape.

graph twoway scatter life school [fweight=pop], msymbol(Oh)

* A key feature of Statas graph twoway family is that we can overlay two or more graphs to build more complex images. 
// For example, to draw a scatterplot of life against school, with hollow circles as marker symbols, we would type

// "graph twoway scatter life school, msymbol(Oh)"

// Simple regression lines (lfit) are a different twoway type. 
// To see the line for life regressed on school, with a line of medium-thick width, type

// "graph twoway lfit life school, lwidth(medthick)"

* But often we want to see the scatterplot and regression line together. 
// That is accomplished by overlaying the lfit graph on top of the scatter graph using one command with || (pipes) to indicate the overlay.

graph twoway scatter life school, msymbol(Oh) ///
|| lfit life school, lwidth(medthick)

// Finally, if we have certain options that should apply to the image as a whole, 
// these can be placed in the command after a final ||.

graph twoway scatter life school, msymbol(Oh) ///
|| lfit life school, lwidth(medthick) ///
|| , ylabel(45(5)85) xlabel(2(2)12) xtick(1(2)13) ///
legend(col(1) ring(0) position(11))

// The legend option in the Figure specifies three things:
* # col(1) The legend should have just one column, and hence two rows.
* # ring(0) The legend is placed within the plot region, instead of outside it. 
// A legend outside the plot region crowds the data into a smaller space.
* # position(11) The legend goes at the 11 oclock position, which in this graph happens to be empty of data.

* # A similar command, "graph twoway qfit", draws a quadratic or second-order polynomial regression curve.

* Scatterplot matrices are not twoway plot types and cannot be overlaid with other graphs, 
// but they involve multiple scatterplots that follow the same marker symbol conventions. 

// A scatterplot matrix is the visual counterpart to a correlation matrix, which can be useful in multivariate analysis. 
// They provide a compact display of relationships between a number of variable pairs, 
// allowing the analyst to scan for signs of nonlinearity, outliers or clustering that might affect statistical modeling. 

* The next Figure shows a scatterplot matrix for five variables from Nations2.dta.

graph matrix gdp school adfert chldmort life, msymbol(oh)

// Nonlinear relationships involving gdp (per capita Gross Domestic Product) stand out prominently in the Figure,
// giving a warning we would not see from the correlation matrix alone.

// "msymbol(oh)" called for small circles as markers. 
// Control of the axes is more complicated, because there are as many axes as variables; 
// type "help graph matrix" for details.

// The "half" option specifies that Figure should include only the lower triangular part of the matrix. 

graph matrix gdp school adfert chldmort life, half msymbol(oh)

// The upper triangular part is symmetrical and basically redundant. 


* ###############################################
* ### 3.4 Line Plots and Connected-Line Plots ###

* Mechanically, connected-line plots (graph twoway connect) are just scatterplots in which the points are connected by line segments. 
* Line plots (graph twoway line) show the line segments without markers for the scatterplot points. 
// Both belong to Statas versatile graph twoway family, which can be overlaid in any combinations. 
// The scatterplot options that control axis labeling and markers work much the same with connected-line and line plots as well. 
// Further options control width, pattern, color and other characteristics of the lines themselves.

* Connected-line and line plots tend to have different uses than scatterplots. 
// For example, they serve well to graph changes in a variable over time. 

// To illustrate, we use dataset Arctic9.dta, which contains 33 years of Arctic sea ice and temperature observations.

use Arctic9.dta, clear
describe

graph twoway line area year, ///
title("Arctic sea ice, September 1979-2011")

* The next Figure adds a second line for sea ice extent (the area covered by at least 15% ice). 

graph twoway line area extent year, xlabel(1980(5)2010) xtitle("") ///
lwidth(medium medthick) lpattern(solid dash) ///
legend(row(2) ring(0) position(9) ///
label(1 "Area") label(2 "Extent") order(2 1)) ///
ylabel(0(1)8, grid gmin gmax) ytitle("Million km{superscript:2}") ///
title("Arctic sea ice, September 1979`=char(150)'2011")

// We label the x axis from 1980 to 2010 in 5-year increments (xlabel(1980(5)2010) 
// The y axis extends down to zero, a possible state of some interest to Arctic observers. 
// Y axis labels go from 0 to 8 in increments of 1, 
// with grid lines including the minimum (0) and maximum (8) labeled values: ylabel(0(1)8, grid gmin gmax).

// The first-named y variable in the Figure command (area) is graphed with a line of medium width and solid pattern. 
// The second y variable (extent) is graphed with a heavier line of medium-thick (medthick) width and dashed pattern. 
// legend() options simplify the labels in the legend, and place extent first corresponding to its higher position in the graph.
// Ice area and extent are measured in millions of square kilometers. 
// The ytitle(Million km{superscript:2}) option displays this as Million km^2 . 
// Type "help graph text" for more about controlling text attributes in graphs. 
// The title option for the Figure inserted ASCII (The American Standard Code for Information Interchange) character 150 (n-dash ()) 
// between 1979 and 2011 by writing 1979`=char(150)'2011. 
// Note the use of left and right single quotes.

* The next Figure overlays a line plot of area vs. year with a connected-line plot 
// (connect, which combines the features of scatter with line) of Arctic temperature vs. year. 

graph twoway line area year, ylabel(0(1)6) yline(0) ///
ytitle("Ice area, million km{superscript:2}") ///
|| connect tempN year, yaxis(2) ylabel(-1(1)2, ///
axis(2)) msymbol(+) ///
ytitle("Arctic temperature anomaly, `=char(186)'C", axis(2)) ///
|| , xlabel(1980(5)2010) xtitle("") ///
legend(row(2) ring(0) position(6) ///
label(1 "Ice area") label(2 "Temperature") order(1 2)) ///
title("Arctic September sea ice and annual temperature, 1979`=char(150)'2011", size(medium))

// The graph shows September sea ice declining as annual Arctic air temperatures rise.

// In the Figure, Arctic temperature anomaly is assigned to yaxis(2), which is the right-hand y axis. 
// Temperature values are marked as plus signs (msymbol(+)). 
// A legend inside the data region at 6 oclock position identifies the two variables. 
// On the right-hand y axis, ASCII character 186 provides the degree symbol for C.

// The Figure illustrated the simplest connect style, in which data points are connected by straight line segments. 
// For more details, see "help connectstyle".

* The next Figure gives a table of ASCII codes, drawn by a convenient utility named "asciiplot". 
// Type "findit asciiplot" for instructions on how to download and install this program.

asciiplot


* ###################################
* ### 3.5 Other Twoway Plot Types ###

* In addition to basic line plots and scatterplots, the graph twoway command can draw a wide variety of other types. 
// Type "help graph twoway" for a complete list.

* #####################################
* ### 3.6 Bar Charts and Pie Charts ###

* # Bar Charts

* The "graph bar" command works well to display relationships involving one or more categorical variables. 

* Consider a cross-national dataset Nations2.dta.

use Nations2.dta, clear
describe region gdp pop

* To make the bar chart readable, start by generating a new variable, gdp1000, expressing Gross Domestic Product in thousands of dollars.

generate gdp1000 = gdp/1000
summarize gdp gdp1000

* The next Figure depicts the mean and median of gdp1000 over values of region, using "graph bar".

graph bar (mean) gdp1000 (median) gdp1000, over(region) ///
ytitle("Per capita GDP, thousands of 2005 US dollars") ///
blabel(bar, format(%3.1f)) ///
bar(1, color(blue)) bar(2, color(orange)) ///
legend(ring(0) position(11) col(2) label(1 "Mean") ///
label(2 "Median") symxsize(*.5))

* The Figure includes labels giving the height of each bar, displayed in numerical format(%3.1f)  
// which means a fixed format with three digits, one of them right of the decimal. 

// "graph bar" can display not only means or medians but also other statistics including various percentiles, minimum, maximum or count. 
// It also could show these statistics for more than one variable, if they have similar scales.

// The legend in the Figure is placed within the data region at 11 oclock: ring(0) position(11).
// It has two columns to parallel the side-by-side arrangement of bars. 
// symxsize(*.5) causes the horizontal (x) dimension of the symbols in the legend to appear at half their default size, 
// which saves space and also makes the symbols more similar to the widths of the bars themselves.
// The graph bar example above specifies a blue color for bar 1 and orange for bar 2. 

* Bar charts can provide clear visualizations of relationships involving many categories and two or more variables. 

* # Saving the graph

graph save Graph graph_bar.gph, replace
graph export graph_bar.png, as(png) replace
graph export graph_bar.eps, as(eps) replace

* The "graph save Graph" command saves the image (by default, temporarily named Graph as seen in the Graph window) in Statas .gph format. 
* We can always specify our own temporary name for a graph, by adding to the graph command an option such as "name(newgraph)". 
// Such temporary names for graphs become important when we have several graphs currently displayed, and want to save or print a particular one. 
// Giving a temporary name to the graph as we create it does not save that graph to disk.
// The temporary and saved-file names need not be the same. 
// Type "help name option" for more discussion.

* "graph export" commands create second and third versions of the same image in different formats. 
// Portable Network Graphics (.png) files are bitmapped images and have a fixed resolution, 
// but they are very compatible and easily shared through Web pages, Powerpoint presentations or other applications. 
// Encapsulated PostScript (.eps) is a high-quality vector format often preferred for publication. 
// Type "help graph export" to learn about other options for this command.

* # Pie Charts

* Pie charts rarely clarify the analysis but are popular for some public presentations. 

* The next Figure illustrates Statas graph pie command, showing the breakdown of world population by region. 
// To make the pie chart readable create a new variable, "popmil" or population in millions.

gen popmil = pop/1000000
summarize pop popmil

graph pie popmil, over(region) pie(2, explode) ///
plabel(_all sum, format(%4.0f))  ///
title("World population in millions, by region")  ///
legend(col(1) position(9))

// The pie(2, explode) option explodes the second pie slice (Americas) for emphasis. 
// plabel(_all sum, format(%4.0f)) requests labels for all of the pie slices, 
// giving the sum of popmil (that is, the total population in millions) for each region. 
// The pie labels have format(%4.0f), meaning a fixed numerical format with four digits, none right of the decimal.
// Type "help graph pie" to see other pie chart options, including methods for differently-organized data. 

// One interesting variation uses the by( ) option to create an image containing multiple small pie charts that can be visually compared.

* # Saving the graph

graph save Graph graph_pie.gph, replace
graph export graph_pie.png, as(png) replace
graph export graph_pie.eps, as(eps) replace


* ###########################################
* ### 3.7 Retrieving and Combining Graphs ###

* Any graph saved in Statas live .gph format can subsequently be retrieved into memory by the "graph use" command. 

graph use graph_bar.gph

* Once the graph is in memory, it is displayed onscreen and can be printed or saved again with a different name or format. 

* Graphs saved on disk can also be combined by the "graph combine" command. This provides a way to bring multiple plots into the same image.

graph combine ///
graph_bar.gph ///
graph_pie.gph ///
, rows(1) altshrink ///
title("Combining Figures", size(medium))

// The "rows(1)" option specified that the Figure should be arranged with the sub-graphs in one rows. 
// "altshrink" calls for alternate scaling of the text within each small image. 

// Note that we can request an overall title (or note, caption, ytitle, xtitle and so forth  not shown) for the combined image. 

// However, we cannot substantially change contents of the sub-graphs themselves.

graph save Graph graph_combined.gph, replace
graph export graph_combined.emf, as(emf) replace


* ########################
* ### 3.8 Graph Editor ###

* The Graph Editor allows us to alter the appearance of a graph currently in memory. 
// A first step is to retrieve this graph into memory.
// Then, in the Graph window, select File > Start Graph Editor, or click the Graph Editor icon.

graph use graph_bar.gph

// The view will change to include a Tools Toolbar on the left margin and an Object Browser on the right. 
// The Tools Toolbar contains a pointer tool for selecting parts of the graph, and other tools to add text, 
// add lines, add markers, and edit the graph grid. 
// The Object Browser presents a hierarchical list of graph contents. 
// Some items are marked with a + sign, and clicking on this + will expand the list to show lower objects within it. 
// We can select objects in the graph by clicking the pointer on their image, or by clicking names in the Object Browser (often easier in complex graphs).


* #####################################################
* ### 3.9 Symmetry and Quantile Plots [extra topic] ###

* Box plots, bar charts and histograms summarize measurement variable distributions, hiding individual data points to clarify overall patterns. 
* Symmetry and quantile plots, on the other hand, include points for every observation. 

* A histogram of the ratio of females to males in the labor forces of 177 countries, from Nations2.dta, appears in the next Figure. 

histogram femlab, norm percent

// A superimposed normal (Gaussian) curve indicates that femlab has a heavier-than-normal left tail 
// (countries with relatively few females in the labor force), 
// and a lighter-than-normal right tail  the definition of negative skew.

* The next Figure depicts this distribution as a symmetry plot. 

symplot femlab

// It plots the distance of the ith observation above the median (vertical) against the distance of the ith observation below the median. 
// All points would lie on the diagonal line if this distribution were symmetrical. 
// Instead, we see that distances below the median grow steadily larger than corresponding distances above the median, a symptom of negative skew.

* Quantile plots automatically calculate what fraction of the observations lie below each data value, 
// and display the results graphically as in the next Figure. 

quantile femlab, xlabel(0(.1)1, grid) ylabel(.2(.1)1, grid)

// Quantile plots provide a reference for someone who does not have the original data at hand. 
// From well-labeled quantile plots, we can estimate order statistics such as median (.5 quantile) or deciles (.1, .2, .3 quantiles and so forth). 
// We could also read a quantile plot to estimate the fraction of observations falling below a given value.

// Quantilenormal plots, also called normal probability plots, compare quantiles of a variables distribution
// with quantiles of a theoretical normal distribution having the same mean and standard deviation. 
// They allow visual inspection for departures from normality in every part of a distribution, 
// which can help guide decisions regarding normality assumptions and efforts to find a normalizing transformation. 

* The next Figure, a quantilenormal plot of femlab, confirms the negative skew noticed earlier. 
// The grid option calls for a set of lines marking the .05, .10, .25 (first quartile), .50 (median), 
// .75 (third quartile), .90, and .95 quantiles of both distributions. 
// The .05, .50, and .95 quantile values are displayed along the top and right-hand axes.

qnorm femlab, grid

* Quantilequantile plots (not shown) resemble quantilenormal plots, but compare quantiles (ordered data points) 
// of two empirical distributions instead of comparing one empirical distribution with a theoretical normal distribution. 
// Type "help quantile" for details on this graphical family.


* ###############################################
* ### 3.10 Adding Text to Graphs [extra topic] ###

* Titles, captions and notes can be added to make graphs more self-explanatory. 
// The default versions of titles and subtitles appear above the data region; 
// notes (which might document the data source, for instance) and captions appear below. 
// These defaults can be overridden.
// Type "help title options" for more information about placement of titles, 
// or "help textbox options" for details concerning their content, including font size and color.
